==> estateplat-common-1.2.4-20210720.054444-817-sources.jar: cn/gtmap/estateplat/model/server/core/BdcSfxm.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * 不动产登记收费项目
 *
 * @author <a href="mailto:zhangxing@gtmap.cn">zx</a>
 * @version 1.0, 2015/11/1
 */
@Table(name = "bdc_sfxm")
public class BdcSfxm implements Serializable {
    @Id
    //收费项目id
    public String sfxmid;
    //收费单信息id
    public String sfxxid;
    //收费项目名称
    public String sfxmmc;
    //序号
    public Integer xh;
    //序号
    public Integer sl;
    //金额
    public Double je;
    //标准
    public String bz;
    //单位
    public String dw;
    //收费项目代码
    public String sfxmdm;
    //标准金额
    public Double bzje;

    /**
     * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
     * @description 收取比例
     */
    private Double sfbl;
    //权利人类型
    private String qlrlx;
    //付费方式
    private String fffs;
    //付费终端
    private String ffzd;
    //是否集中缴费
    private String sfjzjf;
    //减免依据
    private String jmyj;
    //减免金额
    private Double jmje;
    //计算方法
    private String jsff;
    private String bm;
    //结算方式
    private String jsfs;

    private String jfqddh;//缴费清单单号
    private String jfcode;//缴费code,舒城缴费二维码内容
    /**说明事项*/
    private String smsx;
    /**
     * 应收金额
     */
    private Double ysje;

    public String getSfxmid() {
        return sfxmid;
    }

    public void setSfxmid(String sfxmid) {
        this.sfxmid = sfxmid;
    }

    public String getSfxxid() {
        return sfxxid;
    }

    public void setSfxxid(String sfxxid) {
        this.sfxxid = sfxxid;
    }

    public String getSfxmmc() {
        return sfxmmc;
    }

    public void setSfxmmc(String sfxmmc) {
        this.sfxmmc = sfxmmc;
    }

    public Integer getXh() {
        return xh;
    }

    public void setXh(Integer xh) {
        this.xh = xh;
    }

    public Integer getSl() {
        return sl;
    }

    public void setSl(Integer sl) {
        this.sl = sl;
    }

    public Double getJe() {
        return je;
    }

    public void setJe(Double je) {
        this.je = je;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getDw() {
        return dw;
    }

    public void setDw(String dw) {
        this.dw = dw;
    }

    public String getSfxmdm() {
        return sfxmdm;
    }

    public void setSfxmdm(String sfxmdm) {
        this.sfxmdm = sfxmdm;
    }

    public Double getSfbl() {
        return sfbl;
    }

    public void setSfbl(Double sfbl) {
        this.sfbl = sfbl;
    }

    public String getQlrlx() {
        return qlrlx;
    }

    public void setQlrlx(String qlrlx) {
        this.qlrlx = qlrlx;
    }

    public String getFffs() {
        return fffs;
    }

    public void setFffs(String fffs) {
        this.fffs = fffs;
    }

    public String getFfzd() {
        return ffzd;
    }

    public void setFfzd(String ffzd) {
        this.ffzd = ffzd;
    }

    public Double getBzje() {
        return bzje;
    }

    public void setBzje(Double bzje) {
        this.bzje = bzje;
    }

    public String getSfjzjf() {
        return sfjzjf;
    }

    public void setSfjzjf(String sfjzjf) {
        this.sfjzjf = sfjzjf;
    }

    public String getJmyj() {
        return jmyj;
    }

    public void setJmyj(String jmyj) {
        this.jmyj = jmyj;
    }

    public Double getJmje() {
        return jmje;
    }

    public void setJmje(Double jmje) {
        this.jmje = jmje;
    }

    public String getJsff() {
        return jsff;
    }

    public void setJsff(String jsff) {
        this.jsff = jsff;
    }


    public String getBm() {
        return bm;
    }

    public void setBm(String bm) {
        this.bm = bm;
    }

    public String getJsfs() {
        return jsfs;
    }

    public void setJsfs(String jsfs) {
        this.jsfs = jsfs;
    }

    public String getJfqddh() {
        return jfqddh;
    }

    public void setJfqddh(String jfqddh) {
        this.jfqddh = jfqddh;
    }

    public String getJfcode() {
        return jfcode;
    }

    public void setJfcode(String jfcode) {
        this.jfcode = jfcode;
    }

    public String getSmsx() {
        return smsx;
    }

    public void setSmsx(String smsx) {
        this.smsx = smsx;
    }

    public Double getYsje() {
        return ysje;
    }

    public void setYsje(Double ysje) {
        this.ysje = ysje;
    }
}

==> estateplat-common-1.2.4-20210917.094925-879-sources.jar: cn/gtmap/estateplat/model/server/core/BdcSfxm.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * 不动产登记收费项目
 *
 * @author <a href="mailto:zhangxing@gtmap.cn">zx</a>
 * @version 1.0, 2015/11/1
 */
@Table(name = "bdc_sfxm")
public class BdcSfxm implements Serializable {
    @Id
    //收费项目id
    public String sfxmid;
    //收费单信息id
    public String sfxxid;
    //收费项目名称
    public String sfxmmc;
    //序号
    public Integer xh;
    //序号
    public Integer sl;
    //金额
    public Double je;
    //标准
    public String bz;
    //单位
    public String dw;
    //收费项目代码
    public String sfxmdm;
    //标准金额
    public Double bzje;

    /**
     * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
     * @description 收取比例
     */
    private Double sfbl;
    //权利人类型
    private String qlrlx;
    //付费方式
    private String fffs;
    //付费终端
    private String ffzd;
    //是否集中缴费
    private String sfjzjf;
    //减免依据
    private String jmyj;
    //减免金额
    private Double jmje;
    //计算方法
    private String jsff;
    private String bm;
    //结算方式
    private String jsfs;

    private String jfqddh;//缴费清单单号
    private String jfcode;//缴费code,舒城缴费二维码内容
    /**说明事项*/
    private String smsx;
    /**
     * 应收金额
     */
    private Double ysje;

    private String sfzt;//收费状态 0：未收费1：已收费

    public String getSfxmid() {
        return sfxmid;
    }

    public void setSfxmid(String sfxmid) {
        this.sfxmid = sfxmid;
    }

    public String getSfxxid() {
        return sfxxid;
    }

    public void setSfxxid(String sfxxid) {
        this.sfxxid = sfxxid;
    }

    public String getSfxmmc() {
        return sfxmmc;
    }

    public void setSfxmmc(String sfxmmc) {
        this.sfxmmc = sfxmmc;
    }

    public Integer getXh() {
        return xh;
    }

    public void setXh(Integer xh) {
        this.xh = xh;
    }

    public Integer getSl() {
        return sl;
    }

    public void setSl(Integer sl) {
        this.sl = sl;
    }

    public Double getJe() {
        return je;
    }

    public void setJe(Double je) {
        this.je = je;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getDw() {
        return dw;
    }

    public void setDw(String dw) {
        this.dw = dw;
    }

    public String getSfxmdm() {
        return sfxmdm;
    }

    public void setSfxmdm(String sfxmdm) {
        this.sfxmdm = sfxmdm;
    }

    public Double getSfbl() {
        return sfbl;
    }

    public void setSfbl(Double sfbl) {
        this.sfbl = sfbl;
    }

    public String getQlrlx() {
        return qlrlx;
    }

    public void setQlrlx(String qlrlx) {
        this.qlrlx = qlrlx;
    }

    public String getFffs() {
        return fffs;
    }

    public void setFffs(String fffs) {
        this.fffs = fffs;
    }

    public String getFfzd() {
        return ffzd;
    }

    public void setFfzd(String ffzd) {
        this.ffzd = ffzd;
    }

    public Double getBzje() {
        return bzje;
    }

    public void setBzje(Double bzje) {
        this.bzje = bzje;
    }

    public String getSfjzjf() {
        return sfjzjf;
    }

    public void setSfjzjf(String sfjzjf) {
        this.sfjzjf = sfjzjf;
    }

    public String getJmyj() {
        return jmyj;
    }

    public void setJmyj(String jmyj) {
        this.jmyj = jmyj;
    }

    public Double getJmje() {
        return jmje;
    }

    public void setJmje(Double jmje) {
        this.jmje = jmje;
    }

    public String getJsff() {
        return jsff;
    }

    public void setJsff(String jsff) {
        this.jsff = jsff;
    }


    public String getBm() {
        return bm;
    }

    public void setBm(String bm) {
        this.bm = bm;
    }

    public String getJsfs() {
        return jsfs;
    }

    public void setJsfs(String jsfs) {
        this.jsfs = jsfs;
    }

    public String getJfqddh() {
        return jfqddh;
    }

    public void setJfqddh(String jfqddh) {
        this.jfqddh = jfqddh;
    }

    public String getJfcode() {
        return jfcode;
    }

    public void setJfcode(String jfcode) {
        this.jfcode = jfcode;
    }

    public String getSmsx() {
        return smsx;
    }

    public void setSmsx(String smsx) {
        this.smsx = smsx;
    }

    public Double getYsje() {
        return ysje;
    }

    public void setYsje(Double ysje) {
        this.ysje = ysje;
    }

    public String getSfzt() {
        return sfzt;
    }

    public void setSfzt(String sfzt) {
        this.sfzt = sfzt;
    }
}
